# RoleUser

The permissions role assigned to the user. Can be `user`, `billing`, `engineer`, or `superuser`.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | The permissions role assigned to the user. Can be `user`, `billing`, `engineer`, or `superuser`. |  must be one of ["user", "billing", "engineer", "superuser", ]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


